@@ -30,13 +30,26 @@ class User(BaseModel):
     following_count: int
     biography: Optional[str] = ""
     external_url: Optional[str]
+    account_type: Optional[int]
     is_business: bool
 
     public_email: Optional[str]
     contact_phone_number: Optional[str]
+    public_phone_country_code: Optional[str]
+    public_phone_number: Optional[str]
     business_contact_method: Optional[str]
     business_category_name: Optional[str]
     category_name: Optional[str]
+    category: Optional[str]
+
+    address_street: Optional[str]
+    city_id: Optional[str]
+    city_name: Optional[str]
+    latitude: Optional[float]
+    longitude: Optional[float]
+    zip: Optional[str]
+    instagram_location_id: Optional[str]
+    interop_messaging_user_fbid: Optional[str]
 
     _external_url = validator('external_url', allow_reuse=True)(validate_external_url)
 
